#!/bin/bash
if [ -z "$1" ]; then
	echo Need two file names as command line arguments.
	exit
fi

if [ -z "$2" ]; then
	echo Need two file names as command line arguments!
	exit
fi

FILE1=$1
FILE2=$2

#Find the total number of header lines and the total number of lines in the file.
NUM1=`grep @ $FILE1 | wc -l`
NUM2=`grep @ $FILE2 | wc -l`
TOTAL1=`wc -l $FILE1 | cut -f1 -d\ `
TOTAL2=`wc -l $FILE2 | cut -f1 -d\ `


# Send the header lines to a new file.
head -$NUM1 $FILE1 > temp1.txt
head -$NUM2 $FILE2 >> temp1.txt

# Sort the header lines in the new file.
sort temp1.txt > temp2.txt

# Find the header that is duplicated - that is the name of the column we will  join on...
joinAtt1=`uniq -d temp2.txt | cut -f2 -d@`

# Find the index of the column to be joined on.
index1=`grep -n @ $FILE1 | grep $joinAtt1 | cut -f1 -d:`
index2=`grep -n @ $FILE2 | grep $joinAtt1 | cut -f1 -d:`

# Assume that there is not a new line character on the last line...
TABLE1=$((TOTAL1-NUM1+1))
TABLE2=$((TOTAL2-NUM2+1))

# We want to join, but we only want to join on the tail (ie don't include the column headers in the join.
# So, get the tail of the files and save them to a file.
tail -n$TABLE1 $FILE1 | sort -k $index1 > test1.txt
tail -n$TABLE2 $FILE2 | sort -k $index2 > test2.txt

# Join the 'tables' using the files we just created.
join -1 $index1 -2 $index2 test1.txt test2.txt

# Remove the files we created to store temporary results.
rm test1.txt
rm test2.txt
